# Generated by Django 3.2.11 on 2022-07-22 18:40

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_subject", "0132_auto_20220722_1825"),
    ]

    operations = [
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="haemoglobin_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="hct_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="mch_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="mchc_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="mcv_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="platelets_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="rbc_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsfbc",
            name="wbc_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsins",
            name="ins_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsins",
            name="ins_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="albumin_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="alp_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="alt_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="amylase_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="ast_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslft",
            name="ggt_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="chol_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="hdl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="ldl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultslipid",
            name="trig_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="creatinine_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="egfr_drop_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="egfr_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="urea_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="bloodresultsrft",
            name="uric_acid_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="haemoglobin_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="hct_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="mch_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="mchc_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="mcv_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="platelets_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="rbc_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsfbc",
            name="wbc_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsins",
            name="ins_grade",
            field=models.IntegerField(
                blank=True,
                choices=[
                    (0, "Not graded"),
                    (1, "Grade 1"),
                    (2, "Grade 2"),
                    (3, "Grade 3"),
                    (4, "Grade 4"),
                    (5, "Grade 5"),
                ],
                null=True,
                verbose_name="Grade",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsins",
            name="ins_grade_description",
            field=models.CharField(
                blank=True, max_length=250, null=True, verbose_name="Grade description"
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="albumin_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="alp_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="alt_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="amylase_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="ast_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslft",
            name="ggt_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="chol_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="hdl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="ldl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultslipid",
            name="trig_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="creatinine_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="egfr_drop_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="egfr_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="urea_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AddField(
            model_name="historicalbloodresultsrft",
            name="uric_acid_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="ins_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="ins_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="ins_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Insulin",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alp_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="alt_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="amylase_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ast_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ggt_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="egfrdropnotification",
            name="egfr_percent_change",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Copied from RFT result eGFR section.",
                max_digits=10,
                null=True,
                verbose_name="Change from baseline",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="ins_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("=", "="), (">", ">"), (">=", ">="), ("<", "<"), ("<=", "<=")],
                default="=",
                max_length=10,
                null=True,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="ins_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="ins_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0.0),
                    django.core.validators.MaxValueValidator(999.0),
                ],
                verbose_name="Insulin",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alp_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="alt_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="amylase_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ast_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ggt_units",
            field=models.CharField(
                blank=True,
                choices=[("IU/L", "IU/L")],
                max_length=15,
                null=True,
                verbose_name="units",
            ),
        ),
        migrations.AlterField(
            model_name="historicalegfrdropnotification",
            name="egfr_percent_change",
            field=models.DecimalField(
                blank=True,
                decimal_places=2,
                help_text="Copied from RFT result eGFR section.",
                max_digits=10,
                null=True,
                verbose_name="Change from baseline",
            ),
        ),
    ]



import importlib.metadata

from .celery import app as celery_app

try:
    __version__ = importlib.metadata.version(__package__)
except importlib.metadata.PackageNotFoundError:
    __version__ = "unknown"

__all__ = ["__version__", "celery_app"]



# Generated by Django 5.0.1 on 2024-02-13 00:03

import django.core.validators
import edc_model_fields.fields.other_charfield
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0017_complications_dmmedications_dmtreatments_and_more"),
        ("meta_subject", "0165_alter_dmreferralfollowup_healthcare_workers"),
    ]

    operations = [
        migrations.RenameField(
            model_name="dmreferralfollowup",
            old_name="dm_medications_other",
            new_name="other_dm_medications",
        ),
        migrations.RenameField(
            model_name="dmreferralfollowup",
            old_name="investigations_other",
            new_name="other_investigations",
        ),
        migrations.RenameField(
            model_name="historicaldmreferralfollowup",
            old_name="dm_medications_other",
            new_name="other_dm_medications",
        ),
        migrations.RenameField(
            model_name="historicaldmreferralfollowup",
            old_name="investigations_other",
            new_name="other_investigations",
        ),
        migrations.AddField(
            model_name="dmreferralfollowup",
            name="complications_checks_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Was the patient checked for diabetes related complications at this visit?",
            ),
        ),
        migrations.AddField(
            model_name="dmreferralfollowup",
            name="other_complications_checks",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other 'diabetes related complications checked for ', please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="dmreferralfollowup",
            name="treatment_prescribed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Was any treatment prescribed at this visit?",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmreferralfollowup",
            name="complications_checks_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Was the patient checked for diabetes related complications at this visit?",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmreferralfollowup",
            name="other_complications_checks",
            field=edc_model_fields.fields.other_charfield.OtherCharField(
                blank=True,
                max_length=35,
                null=True,
                verbose_name="If other 'diabetes related complications checked for ', please specify ...",
            ),
        ),
        migrations.AddField(
            model_name="historicaldmreferralfollowup",
            name="treatment_prescribed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Was any treatment prescribed at this visit?",
            ),
        ),
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="complications_checks",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.complications",
                verbose_name="If 'Yes, which diabetes related complications were checked for?",
            ),
        ),
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="dm_medications",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.dmmedications",
                verbose_name="If ‘Yes’, please indicate which diabetes drug treatments you are currently taking.",
            ),
        ),
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="dm_treatments",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.dmtreatments",
                verbose_name="What treatment was prescribed?",
            ),
        ),
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="investigations_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Were any further investigations conducted at this visit?",
            ),
        ),
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="visual_score_confirmed",
            field=models.IntegerField(
                blank=True,
                help_text="%",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="visual_score_slider",
            field=models.CharField(
                blank=True, help_text="%", max_length=3, null=True, verbose_name="Visual score"
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreferralfollowup",
            name="investigations_performed",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                default="N/A",
                max_length=25,
                verbose_name="Were any further investigations conducted at this visit?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreferralfollowup",
            name="visual_score_confirmed",
            field=models.IntegerField(
                blank=True,
                help_text="%",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(0),
                    django.core.validators.MaxValueValidator(100),
                ],
                verbose_name="<B><font color='orange'>Interviewer</font></B>: please transcribe the score indicated from above.",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreferralfollowup",
            name="visual_score_slider",
            field=models.CharField(
                blank=True, help_text="%", max_length=3, null=True, verbose_name="Visual score"
            ),
        ),
    ]



from .screening_part_one_admin import ScreeningPartOneAdmin
from .screening_part_three_admin import ScreeningPartThreeAdmin
from .screening_part_two_admin import ScreeningPartTwoAdmin
from .subject_refusal_admin import SubjectRefusalAdmin
from .subject_screening_admin import SubjectScreeningAdmin

__all__ = [
    "ScreeningPartOneAdmin",
    "ScreeningPartThreeAdmin",
    "ScreeningPartTwoAdmin",
    "SubjectRefusalAdmin",
    "SubjectScreeningAdmin",
]



from django.conf import settings
from django.db import models
from edc_model.models import BaseUuidModel
from edc_transfer.model_mixins import SubjectTransferModelMixin


class SubjectTransfer(
    SubjectTransferModelMixin,
    BaseUuidModel,
):
    transfer_reason = models.ManyToManyField(
        f"{settings.LIST_MODEL_APP_LABEL}.transferreasons",
        verbose_name="Reason for transfer",
    )

    class Meta(SubjectTransferModelMixin.Meta, BaseUuidModel.Meta):
        pass



from clinicedc_constants import NOT_APPLICABLE, NULL_STRING
from django.db.models.signals import post_save
from django.dispatch import receiver

from .proxy_models import ScreeningPartThree


@receiver(
    post_save,
    weak=False,
    sender=ScreeningPartThree,
    dispatch_uid="update_p3_ltfu_on_post_save",
)
def update_p3_ltfu_on_post_save(sender, instance, raw, created, **kwargs):  # noqa: ARG001
    """ """
    if not raw and instance.p3_ltfu != NOT_APPLICABLE and instance.part_three_report_datetime:
        msg = "[auto-updated p3 submitted]"
        instance.p3_ltfu = NOT_APPLICABLE
        instance.p3_ltfu_date = None
        instance.p3_ltfu_comment = (
            f"{msg} {instance.p3_ltfu_comment.replace(msg, NULL_STRING) or NULL_STRING}"
        ).strip()
        instance.save_base(update_fields=["p3_ltfu", "p3_ltfu_date", "p3_ltfu_comment"])



from django import forms
from edc_action_item.forms import ActionItemCrfFormMixin
from edc_crf.modelform_mixins import CrfModelFormMixin

from ..form_validators import DeliveryFormValidator
from ..models import Delivery


class DeliveryForm(CrfModelFormMixin, ActionItemCrfFormMixin, forms.ModelForm):
    report_datetime_allowance = 364

    form_validator_cls = DeliveryFormValidator

    class Meta(ActionItemCrfFormMixin.Meta):
        model = Delivery
        fields = "__all__"



# Generated by Django 5.0 on 2024-01-09 23:21

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_consent", "0018_alter_subjectconsent_options_and_more"),
        ("sites", "0002_alter_domain_unique"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="subjectconsent",
            options={
                "default_manager_name": "objects",
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "verbose_name": "Subject Consent",
                "verbose_name_plural": "Subject Consents",
            },
        ),
        migrations.RemoveIndex(
            model_name="subjectconsent",
            name="meta_consen_subject_6fdb8c_idx",
        ),
        migrations.AddField(
            model_name="historicalsubjectconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectreconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="historicalsubjectreconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AddField(
            model_name="subjectreconsent",
            name="locale_created",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale created",
            ),
        ),
        migrations.AddField(
            model_name="subjectreconsent",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                null=True,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="language",
            field=models.CharField(
                choices=[
                    ("sw", "Swahili"),
                    ("en-gb", "British English"),
                    ("en", "English"),
                    ("mas", "Maasai"),
                ],
                help_text="The language used for the consent process will also be used during data collection.",
                max_length=25,
                verbose_name="Language of consent",
            ),
        ),
        migrations.AddIndex(
            model_name="subjectconsent",
            index=models.Index(
                fields=["modified", "created"], name="meta_consen_modifie_0437ee_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="subjectconsent",
            index=models.Index(
                fields=["user_modified", "user_created"],
                name="meta_consen_user_mo_b20eb9_idx",
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectconsent",
            constraint=models.UniqueConstraint(
                fields=("first_name", "dob", "initials", "version"),
                name="meta_consent_subjectconsent_first_uniq",
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectconsent",
            constraint=models.UniqueConstraint(
                fields=(
                    "subject_identifier",
                    "first_name",
                    "dob",
                    "initials",
                    "version",
                ),
                name="meta_consent_subjectconsent_subject_uniq",
            ),
        ),
        migrations.AddConstraint(
            model_name="subjectconsent",
            constraint=models.UniqueConstraint(
                fields=("version", "subject_identifier"),
                name="meta_consent_subjectconsent_version_uniq",
            ),
        ),
    ]



def get_blood_pressure_fields() -> tuple[str, ...]:
    return (
        "sys_blood_pressure_one",
        "dia_blood_pressure_one",
        "sys_blood_pressure_two",
        "dia_blood_pressure_two",
        "severe_htn",
    )


def get_respiratory_o2_fields() -> tuple[str, ...]:
    return ("respiratory_rate",)



# Generated by Django 3.0.4 on 2020-04-16 19:43

import uuid

import _socket
import django.contrib.sites.managers
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django.utils.timezone
import django_revision.revision_field
import edc_model.models.fields.other_charfield
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import edc_vitals.models.fields.blood_pressure
import edc_vitals.models.fields.height
import edc_vitals.models.fields.weight
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("sites", "0002_alter_domain_unique"),
        ("meta_subject", "0017_auto_20200325_0901"),
    ]

    operations = [
        migrations.CreateModel(
            name="HistoricalCoronaKap",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django.utils.timezone.now,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django.utils.timezone.now,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "months_on_art",
                    models.IntegerField(
                        help_text="months",
                        verbose_name="How long has the patient been on antiretroviral therapy?",
                    ),
                ),
                (
                    "dm_aware",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Does the patient know if he/she has diabetes?",
                    ),
                ),
                ("weight", edc_vitals.models.fields.weight.WeightField()),
                ("height", edc_vitals.models.fields.height.HeightField()),
                (
                    "sys_blood_pressure_r1",
                    edc_vitals.models.fields.blood_pressure.SystolicPressureField(null=True),
                ),
                (
                    "dia_blood_pressure_r1",
                    edc_vitals.models.fields.blood_pressure.DiastolicPressureField(null=True),
                ),
                (
                    "married",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Married currently?",
                    ),
                ),
                (
                    "employment_status",
                    models.CharField(
                        choices=[
                            ("working_for_pay", "Working for pay"),
                            ("unemployed", "Unemployed"),
                            (
                                "not_working_for_pay",
                                "Not working for pay (housewife, retired...)",
                            ),
                        ],
                        max_length=25,
                        verbose_name="Employment status",
                    ),
                ),
                (
                    "shared_housing_one",
                    models.IntegerField(
                        verbose_name="How many people live together in your dwelling?"
                    ),
                ),
                (
                    "shared_housing_two",
                    models.IntegerField(
                        verbose_name="In a typically month, how many different people spend more than one night at your current dwelling"
                    ),
                ),
                (
                    "profession",
                    models.CharField(
                        choices=[
                            ("professional", "Professional (e.g. office"),
                            ("labourer", "Labourer"),
                            ("housewife_retired", "Housewife, Retired"),
                            ("self_employed", "Small business, self-employed"),
                            ("OTHER", "Other, specify below"),
                        ],
                        max_length=25,
                        verbose_name="Profession / Employment",
                    ),
                ),
                (
                    "other_profession",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "education",
                    models.CharField(
                        choices=[
                            ("primary", "Up to primary"),
                            ("secondary", "Up to high school"),
                            ("tertiary", "University, college"),
                            ("no_education", "No education"),
                        ],
                        max_length=25,
                        verbose_name="Education level",
                    ),
                ),
                (
                    "health_insurance",
                    models.CharField(
                        choices=[
                            ("work_scheme", "Work scheme health insurance"),
                            ("private", "Private health insurance"),
                            ("no_insurance", "No insurance, I pay"),
                            ("OTHER", "Other, please specify below"),
                        ],
                        max_length=25,
                        verbose_name="Health Insurance",
                    ),
                ),
                (
                    "other_health_insurance",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "personal_health_opinion",
                    models.CharField(
                        choices=[
                            ("excellent", "Excellent"),
                            ("good", "Good"),
                            ("fair", "Fair"),
                            ("poor", "Poor"),
                        ],
                        max_length=25,
                        verbose_name="In your opinion, what is your health like?",
                    ),
                ),
                (
                    "perceived_threat",
                    models.IntegerField(
                        help_text="On a scale from 1-10",
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="How serious of a public health threat is coronavirus",
                    ),
                ),
                (
                    "corona_concern",
                    models.CharField(
                        choices=[
                            ("very", "Very worried"),
                            ("somewhat", "Somewhat worried"),
                            ("a_little", "A little worried"),
                            ("not_at_all", "Not worried at all"),
                        ],
                        max_length=25,
                        verbose_name="How worried are you about getting coronavirus?",
                    ),
                ),
                (
                    "personal_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Do you think you will get corona virus",
                    ),
                ),
                (
                    "family_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="How likely is that you or someone in your family will get sick from the coronavirus",
                    ),
                ),
                (
                    "perc_die",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="What percentage of people who get coronavirus do you think will die",
                    ),
                ),
                (
                    "perc_mild_symptom",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="What percentage of people who get coronavirus do you think will have only mild symptoms",
                    ),
                ),
                (
                    "spread_droplets",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus spreads by droplets from cough and sneezes from people infected with coronavirus",
                    ),
                ),
                (
                    "spread_touch",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus can spread by people touching each other",
                    ),
                ),
                (
                    "spread_sick",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People transmit the virus when they are sick ",
                    ),
                ),
                (
                    "spread_asymptomatic",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People can transmit the virus even when they do not appear to be sick",
                    ),
                ),
                (
                    "severity_age",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The disease is more severe in older people than children",
                    ),
                ),
                (
                    "hot_climate",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus does not survive in the hot climate",
                    ),
                ),
                (
                    "lives_on_materials",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus can live on clothes, plastics, cardboard for a day or more",
                    ),
                ),
                (
                    "spread_touch2",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="You can catch the virus if you touch an infected area and then touch your face or eyes",
                    ),
                ),
                (
                    "symptoms_fever",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fever",
                    ),
                ),
                (
                    "symptoms_headache",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Headache",
                    ),
                ),
                (
                    "symptoms_dry_cough",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Dry persistant cough",
                    ),
                ),
                (
                    "symptoms_body_aches",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Body aches",
                    ),
                ),
                (
                    "symptoms_smell",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Loss of taste and smell",
                    ),
                ),
                (
                    "symptoms_breathing",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fast or difficult breathing",
                    ),
                ),
                (
                    "know_other_symptoms",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Do you know of any other symptoms of a Coronavirus?",
                    ),
                ),
                (
                    "other_symptoms",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Please list any other symptoms of a Corona virus infection that you are aware of",
                    ),
                ),
                (
                    "hot_drinks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink warm water or hot drinks like tea or coffee",
                    ),
                ),
                (
                    "alcohol",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink alcohol, spirits, etc",
                    ),
                ),
                (
                    "wash_hands",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wash hands with soap and warm water virus",
                    ),
                ),
                (
                    "hand_sanitizer",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Use hand sanitisers with alcohol",
                    ),
                ),
                (
                    "avoid_crowds",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Avoid crowded places such as markets and public transport",
                    ),
                ),
                (
                    "face_masks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wear a face mask",
                    ),
                ),
                (
                    "stay_indoors",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Stay indoors",
                    ),
                ),
                (
                    "social_distance",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Keep at least a 2 metre distance from people",
                    ),
                ),
                (
                    "stay_home",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Stay at home and avoid people",
                    ),
                ),
                (
                    "visit_clinic",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to the nearest health facility",
                    ),
                ),
                (
                    "call_nurse",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Call your nurse and tell them you are sick",
                    ),
                ),
                (
                    "take_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Take medicines like chloroquine",
                    ),
                ),
                (
                    "stop_chronic_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Stop taking my chronic disease medicines",
                    ),
                ),
                (
                    "visit_religious",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a religious leader instead of a doctor",
                    ),
                ),
                (
                    "visit_traditional",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a traditional healer instead of a doctor",
                    ),
                ),
                ("history_date", models.DateTimeField()),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.Site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="meta_subject.SubjectVisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Corona Knowledge, Attitudes, and Practices",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": "history_date",
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="CoronaKap",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django.utils.timezone.now,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django.utils.timezone.now,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                (
                    "consent_model",
                    models.CharField(editable=False, max_length=50, null=True),
                ),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "months_on_art",
                    models.IntegerField(
                        help_text="months",
                        verbose_name="How long has the patient been on antiretroviral therapy?",
                    ),
                ),
                (
                    "dm_aware",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Does the patient know if he/she has diabetes?",
                    ),
                ),
                ("weight", edc_vitals.models.fields.weight.WeightField()),
                ("height", edc_vitals.models.fields.height.HeightField()),
                (
                    "sys_blood_pressure_r1",
                    edc_vitals.models.fields.blood_pressure.SystolicPressureField(null=True),
                ),
                (
                    "dia_blood_pressure_r1",
                    edc_vitals.models.fields.blood_pressure.DiastolicPressureField(null=True),
                ),
                (
                    "married",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Married currently?",
                    ),
                ),
                (
                    "employment_status",
                    models.CharField(
                        choices=[
                            ("working_for_pay", "Working for pay"),
                            ("unemployed", "Unemployed"),
                            (
                                "not_working_for_pay",
                                "Not working for pay (housewife, retired...)",
                            ),
                        ],
                        max_length=25,
                        verbose_name="Employment status",
                    ),
                ),
                (
                    "shared_housing_one",
                    models.IntegerField(
                        verbose_name="How many people live together in your dwelling?"
                    ),
                ),
                (
                    "shared_housing_two",
                    models.IntegerField(
                        verbose_name="In a typically month, how many different people spend more than one night at your current dwelling"
                    ),
                ),
                (
                    "profession",
                    models.CharField(
                        choices=[
                            ("professional", "Professional (e.g. office"),
                            ("labourer", "Labourer"),
                            ("housewife_retired", "Housewife, Retired"),
                            ("self_employed", "Small business, self-employed"),
                            ("OTHER", "Other, specify below"),
                        ],
                        max_length=25,
                        verbose_name="Profession / Employment",
                    ),
                ),
                (
                    "other_profession",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "education",
                    models.CharField(
                        choices=[
                            ("primary", "Up to primary"),
                            ("secondary", "Up to high school"),
                            ("tertiary", "University, college"),
                            ("no_education", "No education"),
                        ],
                        max_length=25,
                        verbose_name="Education level",
                    ),
                ),
                (
                    "health_insurance",
                    models.CharField(
                        choices=[
                            ("work_scheme", "Work scheme health insurance"),
                            ("private", "Private health insurance"),
                            ("no_insurance", "No insurance, I pay"),
                            ("OTHER", "Other, please specify below"),
                        ],
                        max_length=25,
                        verbose_name="Health Insurance",
                    ),
                ),
                (
                    "other_health_insurance",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "personal_health_opinion",
                    models.CharField(
                        choices=[
                            ("excellent", "Excellent"),
                            ("good", "Good"),
                            ("fair", "Fair"),
                            ("poor", "Poor"),
                        ],
                        max_length=25,
                        verbose_name="In your opinion, what is your health like?",
                    ),
                ),
                (
                    "perceived_threat",
                    models.IntegerField(
                        help_text="On a scale from 1-10",
                        validators=[
                            django.core.validators.MinValueValidator(1),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="How serious of a public health threat is coronavirus",
                    ),
                ),
                (
                    "corona_concern",
                    models.CharField(
                        choices=[
                            ("very", "Very worried"),
                            ("somewhat", "Somewhat worried"),
                            ("a_little", "A little worried"),
                            ("not_at_all", "Not worried at all"),
                        ],
                        max_length=25,
                        verbose_name="How worried are you about getting coronavirus?",
                    ),
                ),
                (
                    "personal_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Do you think you will get corona virus",
                    ),
                ),
                (
                    "family_infection_likelihood",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="How likely is that you or someone in your family will get sick from the coronavirus",
                    ),
                ),
                (
                    "perc_die",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="What percentage of people who get coronavirus do you think will die",
                    ),
                ),
                (
                    "perc_mild_symptom",
                    models.IntegerField(
                        help_text="On a scale from 0-100",
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(100),
                        ],
                        verbose_name="What percentage of people who get coronavirus do you think will have only mild symptoms",
                    ),
                ),
                (
                    "spread_droplets",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus spreads by droplets from cough and sneezes from people infected with coronavirus",
                    ),
                ),
                (
                    "spread_touch",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus can spread by people touching each other",
                    ),
                ),
                (
                    "spread_sick",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People transmit the virus when they are sick ",
                    ),
                ),
                (
                    "spread_asymptomatic",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="People can transmit the virus even when they do not appear to be sick",
                    ),
                ),
                (
                    "severity_age",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The disease is more severe in older people than children",
                    ),
                ),
                (
                    "hot_climate",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus does not survive in the hot climate",
                    ),
                ),
                (
                    "lives_on_materials",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="The virus can live on clothes, plastics, cardboard for a day or more",
                    ),
                ),
                (
                    "spread_touch2",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="You can catch the virus if you touch an infected area and then touch your face or eyes",
                    ),
                ),
                (
                    "symptoms_fever",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fever",
                    ),
                ),
                (
                    "symptoms_headache",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Headache",
                    ),
                ),
                (
                    "symptoms_dry_cough",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Dry persistant cough",
                    ),
                ),
                (
                    "symptoms_body_aches",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Body aches",
                    ),
                ),
                (
                    "symptoms_smell",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Loss of taste and smell",
                    ),
                ),
                (
                    "symptoms_breathing",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Fast or difficult breathing",
                    ),
                ),
                (
                    "know_other_symptoms",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=25,
                        verbose_name="Do you know of any other symptoms of a Coronavirus?",
                    ),
                ),
                (
                    "other_symptoms",
                    models.TextField(
                        blank=True,
                        max_length=250,
                        null=True,
                        verbose_name="Please list any other symptoms of a Corona virus infection that you are aware of",
                    ),
                ),
                (
                    "hot_drinks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink warm water or hot drinks like tea or coffee",
                    ),
                ),
                (
                    "alcohol",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Drink alcohol, spirits, etc",
                    ),
                ),
                (
                    "wash_hands",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wash hands with soap and warm water virus",
                    ),
                ),
                (
                    "hand_sanitizer",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Use hand sanitisers with alcohol",
                    ),
                ),
                (
                    "avoid_crowds",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Avoid crowded places such as markets and public transport",
                    ),
                ),
                (
                    "face_masks",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Wear a face mask",
                    ),
                ),
                (
                    "stay_indoors",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Stay indoors",
                    ),
                ),
                (
                    "social_distance",
                    models.CharField(
                        choices=[
                            ("true", "True"),
                            ("false", "False"),
                            ("dont_know", "Don't know"),
                        ],
                        max_length=25,
                        verbose_name="Keep at least a 2 metre distance from people",
                    ),
                ),
                (
                    "stay_home",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Stay at home and avoid people",
                    ),
                ),
                (
                    "visit_clinic",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to the nearest health facility",
                    ),
                ),
                (
                    "call_nurse",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Call your nurse and tell them you are sick",
                    ),
                ),
                (
                    "take_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Take medicines like chloroquine",
                    ),
                ),
                (
                    "stop_chronic_meds",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Stop taking my chronic disease medicines",
                    ),
                ),
                (
                    "visit_religious",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a religious leader instead of a doctor",
                    ),
                ),
                (
                    "visit_traditional",
                    models.CharField(
                        choices=[
                            ("very", "Very likely"),
                            ("somewhat", "Somewhat likely"),
                            ("unlikely", "Not very likely, unlikely"),
                            ("not_at_all", "Not at all"),
                        ],
                        max_length=25,
                        verbose_name="Go to a traditional healer instead of a doctor",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.Site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="meta_subject.SubjectVisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "Corona Knowledge, Attitudes, and Practices",
                "verbose_name_plural": "Corona Knowledge, Attitudes, and Practices",
            },
            managers=[
                ("on_site", django.contrib.sites.managers.CurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
    ]



from clinicedc_constants import NULL_STRING, YES
from dateutil.relativedelta import relativedelta
from django.utils import timezone
from faker import Faker
from model_bakery.recipe import Recipe

from .models import DmReferral, PregnancyNotification

fake = Faker()


pregnancynotification = Recipe(
    PregnancyNotification,
    # site=None,
    action_identifier=NULL_STRING,
    subject_identifier=NULL_STRING,
    report_datetime=timezone.now(),
    bhcg_confirmed=YES,
    unconfirmed_details=NULL_STRING,
    edd=timezone.now() + relativedelta(months=6),
)

dmreferral = Recipe(
    DmReferral,
    action_identifier=NULL_STRING,
    subject_identifier=NULL_STRING,
    report_datetime=timezone.now(),
)



# Generated by Django 4.0.5 on 2022-06-30 08:40
from uuid import uuid4

from django.core.exceptions import ObjectDoesNotExist
from django.db import migrations
from edc_action_item.identifiers import ActionIdentifier
from clinicedc_constants import CLOSED, HIGH_PRIORITY, NEW
from edc_visit_schedule.constants import OFFSCHEDULE_ACTION
from tqdm import tqdm


def create_missing_offschedule(apps, schema_editor):
    eos_model_cls = apps.get_model("meta_prn.endofstudy")
    offschedule_model_cls = apps.get_model("meta_prn.offschedule")
    action_item_model_cls = apps.get_model("edc_action_item.actionitem")
    action_type_model_cls = apps.get_model("edc_action_item.actiontype")

    subject_schedule_history_model_cls = apps.get_model(
        "edc_visit_schedule.subjectschedulehistory"
    )
    try:
        action_type = action_type_model_cls.objects.get(name=OFFSCHEDULE_ACTION)
    except ObjectDoesNotExist:
        pass
    else:
        # update subject_schedule_history
        subject_schedule_history_model_cls.objects.filter(
            offschedule_model="meta_prn.endofstudy"
        ).update(offschedule_model="meta_prn.offschedule")

        sql = (
            "Select eos.id, eos.subject_identifier from meta_prn_endofstudy as eos "
            "left join meta_prn_offschedule as off on eos.subject_identifier = off.subject_identifier "
            "where off.id is null"
        )
        qs = eos_model_cls.objects.raw(sql)

        qs = [obj for obj in qs]
        total = len(qs)

        # create missing offschedule model instances
        for eos in tqdm(qs, total=total):
            # create action items model instances
            tracking_identifier = uuid4().hex
            try:
                action_item = action_item_model_cls.objects.get(
                    subject_identifier=eos.subject_identifier, action_type=action_type
                )
            except ObjectDoesNotExist:
                action_item = action_item_model_cls(
                    action_identifier=uuid4().hex.upper(),
                    subject_identifier=eos.subject_identifier,
                    action_type=action_type,
                    report_datetime=eos.offschedule_datetime,
                    priority=HIGH_PRIORITY,
                    status=NEW,
                    auto_created=True,
                    reference_model="meta_prn.offschedule",
                )
                action_item.save()
                action_item.refresh_from_db()
                if not action_item.action_identifier:
                    raise ValueError("Action identifier cannot be null")
            action_item.status = NEW
            action_item.save()
            action_item.refresh_from_db()
            offschedule = offschedule_model_cls(
                subject_identifier=eos.subject_identifier,
                action_identifier=action_item.action_identifier,
                tracking_identifier=tracking_identifier,
                action_item=action_item,
                report_datetime=eos.offschedule_datetime,
                offschedule_datetime=eos.offschedule_datetime,
                site_id=eos.site.id,
            )
            action_item.status = CLOSED
            action_item.save()
            offschedule.save()
            eos.parent_action_item = action_item
            eos.action_item.status = NEW
            eos.action_item.save()
            eos.action_item.refresh_from_db()
            eos.refresh_from_db()
            eos.save()

        for obj in eos_model_cls.objects.all():
            obj.save()


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0034_auto_20220630_1110"),
    ]

    operations = [migrations.RunPython(create_missing_offschedule)]



from clinicedc_constants import OTHER
from edc_form_validators import FormValidator
from edc_prn.modelform_mixins import PrnFormValidatorMixin


class SubjectRefusalFormValidator(PrnFormValidatorMixin, FormValidator):
    def clean(self):
        self.required_if(OTHER, field="reason", field_required="other_reason")



# Generated by Django 5.0.1 on 2024-02-12 22:56

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_lists", "0017_complications_dmmedications_dmtreatments_and_more"),
        ("meta_subject", "0164_dmreferralfollowup_historicaldmreferralfollowup"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmreferralfollowup",
            name="healthcare_workers",
            field=models.ManyToManyField(
                blank=True,
                to="meta_lists.healthcareworkers",
                verbose_name="What type of health care worker did you see?",
            ),
        ),
    ]



import pandas as pd
from django.apps import apps as django_apps
from django.core.exceptions import ObjectDoesNotExist
from django_pandas.io import read_frame
from edc_pdutils.dataframes import get_appointments, get_crf


class InvalidLotNumber(Exception):  # noqa: N818
    pass


def site_cond(df, site_id):
    return (0 == 0) if not site_id else df.site_id == site_id  # noqa: PLR0133


def get_last_imp_visits_df(
    lot_no: str | None = None,
    site_id: int | None = None,
) -> pd.DataFrame:
    """Returns a dataframe of the last IMP visits based on the last
    StudyMedication refill report.

    `assignment` col defaults to "*****" unless a valid `lot_no` is
    provided.
    """
    lot_obj = None
    if lot_no:
        lot_number_model_cls = django_apps.get_model("meta_pharmacy.lotnumber")
        try:
            lot_obj = lot_number_model_cls.objects.get(lot_no=lot_no)
        except ObjectDoesNotExist as e:
            raise ObjectDoesNotExist("The lot number given is invalid") from e

    df_meds = get_crf(
        "meta_subject.studymedication", subject_visit_model="meta_subject.subjectvisit"
    )
    df_meds = (
        df_meds[(df_meds.refill == "Yes") & (site_cond(df_meds, site_id))]
        .groupby(by=["subject_identifier", "site_id"])
        .agg({"endline_visit_code": "max", "endline_visit_datetime": "max"})
        .reset_index()
    )
    df_meds = df_meds.rename(
        columns={
            "endline_visit_code": "imp_visit_code",
            "endline_visit_datetime": "imp_visit_date",
        }
    )
    df_meds.reset_index()

    # merge with OffSchedule
    opts = {} if not site_id else dict(site_id=site_id)
    offschedule_model_cls = django_apps.get_model("meta_prn.offschedule")
    df_off = read_frame(
        offschedule_model_cls.objects.values(
            "subject_identifier", "offschedule_datetime"
        ).filter(**opts),
        verbose=False,
    )
    df_off["offschedule_datetime"] = df_off["offschedule_datetime"].dt.tz_localize(None)
    df_off["offschedule_datetime"] = df_off["offschedule_datetime"].dt.normalize()
    df_off = df_off.set_index("subject_identifier")

    df_meds = df_meds.set_index("subject_identifier")
    df_final = df_meds.merge(
        df_off, left_index=True, right_index=True, how="outer"
    ).reset_index()

    # merge with RandomizationList if lot_obj
    # note: slow to decrypt assignment
    if lot_obj:
        rando_model_cls = django_apps.get_model("meta_rando.randomizationlist")
        qs = rando_model_cls.objects.values("subject_identifier", "assignment").filter(
            assignment=lot_obj.assignment
        )
        df_rando = read_frame(qs, verbose=False)
        df_final = df_final.merge(df_rando, on="subject_identifier", how="left")
    else:
        df_final["assignment"] = "*****"

    # merge in appts
    df_appt = (
        get_appointments()
        .groupby(by=["subject_identifier"])
        .agg({"next_visit_code": "max", "next_appt_datetime": "max"})
        .reset_index()
    )
    df_final = df_final.merge(
        df_appt[["subject_identifier", "next_visit_code", "next_appt_datetime"]],
        on="subject_identifier",
        how="left",
    )
    df_final = df_final[(df_final.offschedule_datetime.isna()) & (df_final.assignment.notna())]

    # Filter out subjects off_schedule.
    # If lot_obj, filter out those with alternative assignment.
    df_final = df_final[(df_final.offschedule_datetime.isna()) & (df_final.assignment.notna())]
    df_final = df_final.drop(columns=["offschedule_datetime"])

    # calculate days since the IMP visit
    df_final["days_since"] = pd.to_datetime("today").normalize() - df_final.imp_visit_date
    df_final["days_until"] = df_final.next_appt_datetime - pd.to_datetime("today").normalize()
    return df_final.reset_index()



from edc_mnsi.model_mixins import MnsiModelMixin
from edc_model.models import BaseUuidModel

from ..model_mixins import CrfModelMixin


class Mnsi(MnsiModelMixin, CrfModelMixin, BaseUuidModel):
    class Meta(MnsiModelMixin.Meta, CrfModelMixin.Meta, BaseUuidModel.Meta):
        pass



from clinicedc_constants import NO
from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from edc_constants.choices import YES_NO
from edc_vitals.models import WeightField


class VitalsFieldsModelMixin(models.Model):
    weight = WeightField(null=True)

    waist_circumference_measured = models.CharField(
        verbose_name="Was the patient's waist circumference measured today?",
        max_length=15,
        choices=YES_NO,
        help_text=(
            "Waist circumference may be provided at anytime "
            "but is required at 36 and 48 months"
        ),
        default=NO,
    )

    waist_circumference = models.DecimalField(
        verbose_name="Waist circumference",
        max_digits=5,
        decimal_places=1,
        validators=[MinValueValidator(50.0), MaxValueValidator(175.0)],
        help_text="in centimeters",
        null=True,
        blank=True,
    )

    waist_circumference_comment = models.TextField(
        verbose_name="If waist circumference not measured, please explain ...",
        help_text=(
            "A reason not measured may be provided at anytime "
            "but is required at 36 and 48 months"
        ),
        default="",
        blank=True,
    )

    # 10
    heart_rate = models.IntegerField(
        verbose_name="Heart rate:",
        validators=[MinValueValidator(30), MaxValueValidator(200)],
        help_text="BPM",
    )

    # 11
    respiratory_rate = models.IntegerField(
        verbose_name="Respiratory rate:",
        validators=[MinValueValidator(6), MaxValueValidator(50)],
        help_text="breaths/min",
        null=True,
        blank=True,
    )

    # 12
    oxygen_saturation = models.IntegerField(
        verbose_name="Oxygen saturation:",
        validators=[MinValueValidator(1), MaxValueValidator(999)],
        help_text="%",
        null=True,
        blank=True,
    )

    temperature = models.DecimalField(
        verbose_name="Temperature:",
        validators=[MinValueValidator(30), MaxValueValidator(45)],
        decimal_places=1,
        max_digits=3,
        help_text="in degrees Celcius",
    )

    class Meta:
        abstract = True



from .subject_consent_admin import SubjectConsentAdmin
from .subject_consent_v1_admin import SubjectConsentV1Admin
from .subject_consent_v1_ext_admin import SubjectConsentV1ExtAdmin

__all__ = [
    "SubjectConsentAdmin",
    "SubjectConsentV1Admin",
    "SubjectConsentV1ExtAdmin",
]



from .autocomplete_admin import ArvRegimensAdmin
from .birth_outcome_admin import BirthOutcomesAdmin
from .blood_results import (
    BloodResultsFbcAdmin,
    BloodResultsLftAdmin,
    BloodResultsLipidsAdmin,
    BloodResultsRftAdmin,
)
from .complications_admin import ComplicationsAdmin
from .complications_glycemia_admin import ComplicationsGlycemiaAdmin
from .concomitant_medication_admin import ConcomitantMedicationAdmin
from .delivery_admin import DeliveryAdmin
from .diabetes import DmEndpointAdmin, DmFollowupAdmin
from .egfr_drop_notification_admin import EgfrDropNotificationAdmin
from .eq5d3l_admin import Eq5d3lAdmin
from .followup_examination_admin import FollowupExaminationAdmin
from .followup_vitals_admin import FollowupVitalsAdmin
from .glucose_admin import GlucoseAdmin
from .glucose_fbg_admin import GlucoseFbgAdmin
from .health_economics import HealthEconomicsSimpleAdmin, HealthEconomicsUpdateAdmin
from .hepatitis_test_admin import HepatitisTestAdmin
from .hiv_exit_review_admin import HivExitReviewAdmin
from .malaria_test_admin import MalariaTestAdmin
from .medication_adherence_admin import MedicationAdherenceAdmin
from .mnsi_admin import MnsiAdmin
from .next_appointment_admin import NextAppointmentAdmin
from .other_arv_regimens_admin import OtherArvRegimensAdmin
from .patient_history_admin import PatientHistoryAdmin
from .physical_exam_admin import PhysicalExamAdmin
from .pregnancy_update_admin import PregnancyUpdateAdmin
from .sf12_admin import Sf12Admin
from .study_medication_admin import StudyMedicationAdmin
from .subject_requisition_admin import SubjectRequisitionAdmin
from .subject_visit_admin import SubjectVisitAdmin
from .subject_visit_missed_admin import SubjectVisitMissedAdmin
from .urine_dipstick_test_admin import UrineDipstickTestAdmin
from .urine_pregnancy_admin import UrinePregnancyAdmin

__all__ = [
    "ArvRegimensAdmin",
    "BirthOutcomesAdmin",
    "BloodResultsFbcAdmin",
    "BloodResultsLftAdmin",
    "BloodResultsLipidsAdmin",
    "BloodResultsRftAdmin",
    "ComplicationsAdmin",
    "ComplicationsGlycemiaAdmin",
    "ConcomitantMedicationAdmin",
    "DeliveryAdmin",
    "DmEndpointAdmin",
    "DmFollowupAdmin",
    "EgfrDropNotificationAdmin",
    "Eq5d3lAdmin",
    "FollowupExaminationAdmin",
    "FollowupVitalsAdmin",
    "GlucoseAdmin",
    "GlucoseFbgAdmin",
    "HealthEconomicsSimpleAdmin",
    "HealthEconomicsUpdateAdmin",
    "HepatitisTestAdmin",
    "HivExitReviewAdmin",
    "MalariaTestAdmin",
    "MedicationAdherenceAdmin",
    "MnsiAdmin",
    "NextAppointmentAdmin",
    "OtherArvRegimensAdmin",
    "PatientHistoryAdmin",
    "PhysicalExamAdmin",
    "PregnancyUpdateAdmin",
    "Sf12Admin",
    "StudyMedicationAdmin",
    "SubjectRequisitionAdmin",
    "SubjectVisitAdmin",
    "SubjectVisitMissedAdmin",
    "UrineDipstickTestAdmin",
    "UrinePregnancyAdmin",
]



# Generated by Django 4.2.5 on 2023-10-17 22:25

import _socket
from django.db import migrations, models
import django_audit_fields.fields.hostname_modification_field
import edc_action_item.managers
import edc_adverse_event.model_mixins.death_report.death_report_tmg_model_mixin


class Migration(migrations.Migration):
    dependencies = [
        ("meta_ae", "0018_alter_deathreporttmg_cause_of_death_agreed_and_more"),
    ]

    operations = [
        migrations.AlterModelManagers(
            name="aefollowup",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="aeinitial",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="aesusar",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="aetmg",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="deathreport",
            managers=[
                ("objects", edc_action_item.managers.ActionIdentifierModelManager()),
                ("on_site", edc_action_item.managers.ActionIdentifierSiteManager()),
            ],
        ),
        migrations.AlterModelManagers(
            name="deathreporttmg",
            managers=[
                (
                    "objects",
                    edc_adverse_event.model_mixins.death_report.death_report_tmg_model_mixin.DeathReportTmgManager(),
                ),
                (
                    "on_site",
                    edc_adverse_event.model_mixins.death_report.death_report_tmg_model_mixin.DeathReportTmgSiteManager(),
                ),
            ],
        ),
        migrations.AlterField(
            model_name="aefollowup",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aefollowup",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aefollowup",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aefollowup",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aeinitial",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aelocalreview",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aelocalreview",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aelocalreview",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aelocalreview",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aesponsorreview",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aesponsorreview",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aesponsorreview",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aesponsorreview",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aesusar",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="aetmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="deathreporttmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaefollowup",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaeinitial",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaesusar",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalaetmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmg",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="device_created",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device created"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="device_modified",
            field=models.CharField(blank=True, max_length=10, verbose_name="Device modified"),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="hostname_created",
            field=models.CharField(
                blank=True,
                default=_socket.gethostname,
                help_text="System field. (modified on create only)",
                max_length=60,
                verbose_name="Hostname created",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreporttmgsecond",
            name="hostname_modified",
            field=django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                blank=True,
                help_text="System field. (modified on every save)",
                max_length=50,
                verbose_name="Hostname modified",
            ),
        ),
    ]



# Generated by Django 3.2.11 on 2022-01-28 14:19

import django.core.validators
import django_crypto_fields.fields.firstname_field
import django_crypto_fields.fields.lastname_field
from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("meta_consent", "0006_auto_20210911_2036"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="first_name",
            field=django_crypto_fields.fields.firstname_field.FirstnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="last_name",
            field=django_crypto_fields.fields.lastname_field.LastnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
                verbose_name="Surname",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="first_name",
            field=django_crypto_fields.fields.firstname_field.FirstnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="last_name",
            field=django_crypto_fields.fields.lastname_field.LastnameField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
                verbose_name="Surname",
            ),
        ),
    ]



# Generated by Django 5.2.6 on 2025-09-24 05:45

import django.utils.timezone
import django_revision.revision_field
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_pharmacy", "0009_remove_historicalrx_slug"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicallabeldata",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="gender",
            field=models.CharField(default="", max_length=5),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="reference",
            field=models.CharField(
                db_index=True, default="", help_text="Bottle reference", max_length=10
            ),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="site_name",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicallabeldata",
            name="subject_identifier",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="action_identifier",
            field=models.CharField(
                blank=True, db_index=True, default="", max_length=50
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="action_item_reason",
            field=models.TextField(default="", editable=False),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="clinician_initials",
            field=models.CharField(default="", max_length=3),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="notes",
            field=models.TextField(
                blank=True,
                default="",
                help_text="Private notes for pharmacist only",
                max_length=250,
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="parent_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to parent reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="rando_sid",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="randomizer_name",
            field=models.CharField(blank=True, default="", max_length=25),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="related_action_identifier",
            field=models.CharField(
                blank=True,
                default="",
                help_text="action identifier that links to related reference model instance.",
                max_length=30,
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="report_datetime",
            field=models.DateTimeField(default=django.utils.timezone.now),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalrx",
            name="rx_date",
            field=models.DateField(
                default=django.utils.timezone.now, verbose_name="Date RX written"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubstitutions",
            name="updated_subject_identifier",
            field=models.CharField(
                blank=True, default="", max_length=50, verbose_name="Taken from subject"
            ),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="gender",
            field=models.CharField(default="", max_length=5),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="reference",
            field=models.CharField(
                default="", help_text="Bottle reference", max_length=10, unique=True
            ),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="site_name",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="labeldata",
            name="subject_identifier",
            field=models.CharField(default="", max_length=15),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="device_created",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device created"
            ),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="device_modified",
            field=models.CharField(
                blank=True, default="", max_length=10, verbose_name="Device modified"
            ),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="locale_created",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale created",
            ),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="locale_modified",
            field=models.CharField(
                blank=True,
                default="",
                help_text="Auto-updated by Modeladmin",
                max_length=10,
                verbose_name="Locale modified",
            ),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="revision",
            field=django_revision.revision_field.RevisionField(
                blank=True,
                default="",
                editable=False,
                help_text="System field. From git repository (tag:branch:commit), project metadata, project toml, project VERSION, or settings.",
                max_length=75,
                verbose_name="Revision",
            ),
        ),
        migrations.AlterField(
            model_name="substitutions",
            name="updated_subject_identifier",
            field=models.CharField(
                blank=True, default="", max_length=50, verbose_name="Taken from subject"
            ),
        ),
    ]



import pandas as pd
from edc_analytics.custom_tables import (
    AgeTable,
    ArtTable,
    BmiTable,
    BpTable,
    FastingTable,
    FbgOgttTable,
    FbgTable,
    GenderTable,
    HbA1cTable,
    OgttTable,
    WaistCircumferenceTable,
)
from edc_analytics.data import Data

from .dataframes import get_glucose_tested_only_df, get_screening_df
from .tables import EligibleP12Table, HasDmTable


def get_tables() -> dict[str, Data]:
    """
    results = get_table()
    results.get("fbg").to_csv(folder="/Users/erikvw/Documents/")
    """
    df_screening = get_screening_df()
    df_has_dm = df_screening[(df_screening["has_dm"] == "Yes")]
    df_no_dm = df_screening[(df_screening["has_dm"] == "No")]
    df_fbg = get_glucose_tested_only_df(df_screening)

    df_not_tested = df_no_dm.copy()
    df_not_eligible_p1p2 = df_not_tested[
        ~(
            (df_not_tested["eligible_part_one"] == "Yes")
            & (df_not_tested["eligible_part_two"] == "Yes")
        )
    ]
    df_not_tested = df_not_tested.drop(df_not_eligible_p1p2.index).drop(df_fbg.index)

    df_stats = pd.DataFrame(
        {
            "df": ["df_screening", "df_has_dm", "df_no_dm", "df_not_tested", "df_fbg"],
            "count": [
                len(df_screening),
                len(df_has_dm),
                len(df_no_dm),
                len(df_not_tested),
                len(df_fbg),
            ],
        }
    )

    results = {"stats": df_stats}
    for key, df in {
        "screening": df_screening,
        "has_dm": df_has_dm,
        "no_dm": df_no_dm,
        "not_tested": df_not_tested,
        "fbg": df_fbg,
    }.items():
        dfs = []
        for tbl_cls in [
            GenderTable,
            AgeTable,
            WaistCircumferenceTable,
            BmiTable,
            BpTable,
            ArtTable,
            FastingTable,
            FbgTable,
            OgttTable,
            FbgOgttTable,
            HbA1cTable,
            EligibleP12Table,
            HasDmTable,
        ]:
            tbl = tbl_cls(main_df=df)
            dfs.append(tbl.table_df)
        results.update({key: Data(key, pd.concat(list(dfs)), df, "meta3")})
    return results



# Generated by Django 4.2.11 on 2024-03-27 19:41

import django.core.validators
from django.db import migrations
import django_crypto_fields.fields.encrypted_char_field
import edc_consent.validators


class Migration(migrations.Migration):

    dependencies = [
        ("meta_consent", "0024_historicalsubjectconsentv1"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="first_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="guardian_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Required only if participant is a minor.<BR>Format is 'LASTNAME, FIRSTNAME'. All uppercase separated by a comma. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_consent.validators.FullNameValidator()],
                verbose_name="Guardian's last and first name",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsent",
            name="last_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
                verbose_name="Surname",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="first_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="guardian_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Required only if participant is a minor.<BR>Format is 'LASTNAME, FIRSTNAME'. All uppercase separated by a comma. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_consent.validators.FullNameValidator()],
                verbose_name="Guardian's last and first name",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectconsentv1",
            name="last_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
                verbose_name="Surname",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="first_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="guardian_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Required only if participant is a minor.<BR>Format is 'LASTNAME, FIRSTNAME'. All uppercase separated by a comma. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[edc_consent.validators.FullNameValidator()],
                verbose_name="Guardian's last and first name",
            ),
        ),
        migrations.AlterField(
            model_name="subjectconsent",
            name="last_name",
            field=django_crypto_fields.fields.encrypted_char_field.EncryptedCharField(
                blank=True,
                help_text="Use UPPERCASE letters only. (Encryption: RSA local)",
                max_length=71,
                null=True,
                validators=[
                    django.core.validators.RegexValidator(
                        message="Ensure name consist of letters only in upper case",
                        regex="^([A-Z]+$|[A-Z]+\\ [A-Z]+)$",
                    )
                ],
                verbose_name="Surname",
            ),
        ),
    ]



from clinicedc_constants import NULL_STRING
from django.db import models
from edc_action_item.models import ActionModelMixin
from edc_identifier.model_mixins import UniqueSubjectIdentifierFieldMixin
from edc_model.models import BaseUuidModel
from edc_sites.model_mixins import SiteModelMixin
from edc_utils.date import get_utcnow

from ..constants import DM_REFFERAL_ACTION


class DmReferral(
    SiteModelMixin,
    ActionModelMixin,
    UniqueSubjectIdentifierFieldMixin,
    BaseUuidModel,
):
    action_name = DM_REFFERAL_ACTION

    report_datetime = models.DateTimeField(
        verbose_name="Report date and time", default=get_utcnow
    )

    referral_date = models.DateField(
        verbose_name="Date of referral to diabetes clinic",
    )

    referral_note = models.TextField(
        verbose_name=(
            "Please provide a brief history of the "
            "diabetes diagnosis that lead to this referral"
        ),
        default=NULL_STRING,
        blank=False,
    )

    class Meta(ActionModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Diabetes referral"
        verbose_name_plural = "Diabetes referral"



from clinicedc_constants import NOT_APPLICABLE
from django.contrib import admin
from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from edc_constants.choices import NO, YES_NO, YES_NO_PENDING_NA_GLUCOSE_SCREENING
from edc_glucose.model_mixin_factories import (
    fasting_model_mixin_factory,
    fbg_model_mixin_factory,
    ogtt_model_mixin_factory,
)
from edc_lab.choices import GLUCOSE_UNITS, SERUM_CREATININE_UNITS
from edc_vitals.model_mixins import (
    BloodPressureModelMixin,
    SimpleBloodPressureModelMixin,
    WeightHeightBmiModelMixin,
)

from .creatinine_fields_model_mixin import CreatinineModelFieldsMixin


class FbgModelMixin(
    fbg_model_mixin_factory(
        "fbg",
        fbg_units=models.CharField(
            verbose_name="FBG units",
            max_length=15,
            choices=GLUCOSE_UNITS,
            null=True,
            blank=True,
        ),
    ),
    fbg_model_mixin_factory(
        "fbg2",
        fbg2_units=models.CharField(
            verbose_name="FBG units",
            max_length=15,
            choices=GLUCOSE_UNITS,
            null=True,
            blank=True,
        ),
    ),
):
    class Meta:
        abstract = True


class OgttModelMixin(
    ogtt_model_mixin_factory(
        "ogtt",
        ogtt_units=models.CharField(
            verbose_name="OGTT Units",
            max_length=15,
            choices=GLUCOSE_UNITS,
            null=True,
            blank=True,
        ),
    ),
    ogtt_model_mixin_factory(
        "ogtt2",
        ogtt2_units=models.CharField(
            verbose_name="Repeat OGTT Units",
            max_length=15,
            choices=GLUCOSE_UNITS,
            null=True,
            blank=True,
        ),
    ),
    models.Model,
):
    class Meta:
        abstract = True


class PartThreeFieldsModelMixin(
    fasting_model_mixin_factory(
        None,
        fasting=models.CharField(
            verbose_name="Has the participant fasted?",
            max_length=15,
            choices=YES_NO,
            null=True,
            blank=False,
            help_text="As reported by patient",
        ),
    ),
    fasting_model_mixin_factory("repeat"),
    FbgModelMixin,
    OgttModelMixin,
    CreatinineModelFieldsMixin,
    BloodPressureModelMixin,
    SimpleBloodPressureModelMixin,
    WeightHeightBmiModelMixin,
    models.Model,
):
    repeat_glucose_opinion = models.CharField(
        verbose_name=(
            "In opinion of the clinician, should the glucose measurements be repeated?"
        ),
        max_length=15,
        choices=YES_NO,
        default=NO,
        help_text=(
            "If repeated, must be at least 3 days after the first glucose measures (FBG, OGTT)"
        ),
    )

    repeat_appt_datetime = models.DateTimeField(
        verbose_name="Appointment date for repeat glucose testing",
        null=True,
        blank=True,
        help_text="must be at least 3 days after the first glucose measures (FBG, OGTT)",
    )

    repeat_glucose_performed = models.CharField(
        verbose_name="Were the glucose measurements repeated?",
        max_length=15,
        choices=YES_NO_PENDING_NA_GLUCOSE_SCREENING,
        default=NOT_APPLICABLE,
        help_text="Select YES when you are ready to enter the repeat results",
    )

    creatinine_units = models.CharField(
        verbose_name="Units (creatinine)",
        max_length=15,
        choices=SERUM_CREATININE_UNITS,
        default="",
        blank=True,
    )

    part_three_report_datetime = models.DateTimeField(
        verbose_name="Part 3 report date and time",
        null=True,
        blank=False,
        help_text="Date and time of report.",
    )

    waist_circumference = models.DecimalField(
        verbose_name="Waist circumference",
        max_digits=5,
        decimal_places=1,
        validators=[MinValueValidator(50.0), MaxValueValidator(175.0)],
        null=True,
        blank=True,
        help_text="in centimeters",
    )

    hba1c_performed = models.CharField(
        verbose_name="Was the HbA1c performed?",
        max_length=15,
        choices=YES_NO,
        default=NO,
        help_text="",
    )

    hba1c_datetime = models.DateTimeField(
        verbose_name="HbA1c date and time",
        null=True,
        blank=True,
        help_text="Date and time of result.",
    )
    hba1c_value = models.DecimalField(
        verbose_name="HbA1c",
        max_digits=8,
        decimal_places=2,
        null=True,
        blank=True,
        help_text="in %",
    )

    creatinine_performed = models.CharField(
        verbose_name="Was the serum creatinine performed?",
        max_length=15,
        choices=YES_NO,
        default=NO,
        help_text="",
    )

    @admin.display(description="P3 repeat appt", ordering="repeat_appt_datetime")
    def p3_repeat_appt(self):
        return self.repeat_appt_datetime

    class Meta:  # noqa: DJ012
        abstract = True



from .calculated_model_mixin import CalculatedModelMixin
from .eligibility_model_mixin import EligibilityModelMixin
from .part_one_fields_model_mixin import PartOneFieldsModelMixin
from .part_three_fields_model_mixin import PartThreeFieldsModelMixin
from .part_two_fields_model_mixin import PartTwoFieldsModelMixin

__all__ = [
    "CalculatedModelMixin",
    "EligibilityModelMixin",
    "PartOneFieldsModelMixin",
    "PartThreeFieldsModelMixin",
    "PartTwoFieldsModelMixin",
]



# Generated by Django 4.2.11 on 2024-04-05 20:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0182_rename_dmreferralfollowup_dmfollowup_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmfollowup",
            name="on_dm_medications",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Are you currently taking any drug therapy for diabetes?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmfollowup",
            name="on_dm_medications",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="Are you currently taking any drug therapy for diabetes?",
            ),
        ),
    ]



# Generated by Django 4.2.11 on 2024-05-15 23:16

from django.db import migrations, models
import edc_model.validators.date


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0190_dmdiagnosis_dx_no_tmg_reason_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="dmdiagnosis",
            name="dx_no_tmg_reason",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If NO, please explain why this case was not discussed with the TMG",
            ),
        ),
        migrations.AlterField(
            model_name="dmdiagnosis",
            name="dx_tmg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If YES, provide the date of the TMG discussion",
            ),
        ),
        migrations.AlterField(
            model_name="glucosefbg",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result date and time of FBG",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmdiagnosis",
            name="dx_no_tmg_reason",
            field=models.TextField(
                blank=True,
                null=True,
                verbose_name="If NO, please explain why this case was not discussed with the TMG",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmdiagnosis",
            name="dx_tmg_date",
            field=models.DateField(
                blank=True,
                null=True,
                verbose_name="If YES, provide the date of the TMG discussion",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucosefbg",
            name="assay_datetime",
            field=models.DateTimeField(
                blank=True,
                null=True,
                validators=[edc_model.validators.date.datetime_not_future],
                verbose_name="Result date and time of FBG",
            ),
        ),
    ]



# Generated by Django 3.2.4 on 2021-08-09 14:44

from django.db import migrations, models


class Migration(migrations.Migration):
    """Added as a fake. Needed it to repair a test DB"""

    dependencies = [
        ("meta_subject", "0073_auto_20210809_0055"),
    ]

    operations = []



from django import forms
from edc_form_validators import FormValidatorMixin
from edc_screening.modelform_mixins import AlreadyConsentedFormMixin

from ..form_validators import ScreeningPartTwoFormValidator
from ..models import ScreeningPartTwo
from .field_lists import part_two_fields


class ScreeningPartTwoForm(AlreadyConsentedFormMixin, FormValidatorMixin, forms.ModelForm):
    form_validator_cls = ScreeningPartTwoFormValidator

    AUTO_NUMBER_START = 17

    class Meta:
        model = ScreeningPartTwo
        fields = part_two_fields
        help_texts = {"contact_number": "(Encryption: RSA local)"}  # noqa: RUF012



from edc_protocol.research_protocol_config import ResearchProtocolConfig

from .patterns import screening_identifier
from .views import (
    AeListboardView,
    DeathReportListboardView,
    ScreeningListboardView,
    SubjectDashboardView,
    SubjectListboardView,
)

app_name = "meta_dashboard"

urlpatterns = SubjectListboardView.urls(
    namespace=app_name,
    url_names_key="subject_listboard_url",
    identifier_pattern=ResearchProtocolConfig().subject_identifier_pattern,
)
urlpatterns += ScreeningListboardView.urls(
    namespace=app_name,
    url_names_key="screening_listboard_url",
    identifier_label="screening_identifier",
    identifier_pattern=screening_identifier,
)
urlpatterns += SubjectDashboardView.urls(
    namespace=app_name,
    url_names_key="subject_dashboard_url",
    identifier_pattern=ResearchProtocolConfig().subject_identifier_pattern,
)

urlpatterns += AeListboardView.urls(
    namespace=app_name,
    url_names_key="ae_listboard_url",
    identifier_pattern=ResearchProtocolConfig().subject_identifier_pattern,
)
urlpatterns += DeathReportListboardView.urls(
    namespace=app_name,
    url_names_key="death_report_listboard_url",
    identifier_pattern=ResearchProtocolConfig().subject_identifier_pattern,
)



# Generated by Django 5.0.8 on 2024-08-21 13:48

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0209_remove_historicaldmdxresult_dm_diagnosis_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="dmdxresult",
            name="dm_diagnosis",
        ),
        migrations.RemoveField(
            model_name="dmdxresult",
            name="site",
        ),
        migrations.RemoveField(
            model_name="historicaldmdxresult",
            name="dm_diagnosis",
        ),
        migrations.RemoveField(
            model_name="historicaldmdxresult",
            name="history_user",
        ),
        migrations.RemoveField(
            model_name="historicaldmdxresult",
            name="site",
        ),
        migrations.AlterModelOptions(
            name="dmendpoint",
            options={
                "default_manager_name": "objects",
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
                "verbose_name": "Diabetes endpoint",
                "verbose_name_plural": "Diabetes endpoint",
            },
        ),
        migrations.AlterModelOptions(
            name="historicaldmendpoint",
            options={
                "get_latest_by": ("history_date", "history_id"),
                "ordering": ("-history_date", "-history_id"),
                "verbose_name": "historical Diabetes endpoint",
                "verbose_name_plural": "historical Diabetes endpoint",
            },
        ),
        migrations.RenameIndex(
            model_name="dmendpoint",
            new_name="meta_subjec_subject_03eaba_idx",
            old_name="meta_subjec_subject_40b1c1_idx",
        ),
        migrations.RenameIndex(
            model_name="dmendpoint",
            new_name="meta_subjec_subject_605359_idx",
            old_name="meta_subjec_subject_2059c2_idx",
        ),
        migrations.AlterField(
            model_name="dmendpoint",
            name="dx_date",
            field=models.DateField(verbose_name="Date endpoint reached"),
        ),
        migrations.AlterField(
            model_name="dmendpoint",
            name="dx_initiated_by",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="What initiated the diagnosis",
            ),
        ),
        migrations.AlterField(
            model_name="dmendpoint",
            name="dx_tmg",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("QUESTION_RETIRED", "Question retired"),
                ],
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Was this case discussed with the TMG?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmendpoint",
            name="dx_date",
            field=models.DateField(verbose_name="Date endpoint reached"),
        ),
        migrations.AlterField(
            model_name="historicaldmendpoint",
            name="dx_initiated_by",
            field=models.CharField(
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="What initiated the diagnosis",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmendpoint",
            name="dx_tmg",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("QUESTION_RETIRED", "Question retired"),
                ],
                default="QUESTION_RETIRED",
                max_length=25,
                verbose_name="Was this case discussed with the TMG?",
            ),
        ),
        migrations.DeleteModel(
            name="DmDxResult",
        ),
        migrations.DeleteModel(
            name="HistoricalDmDxResult",
        ),
    ]



# Generated by Django 4.0.5 on 2022-07-03 13:42

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("meta_prn", "0039_historicaloffstudymedication_reason_other_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="historicaloffstudymedication",
            name="expected_restart_date",
        ),
        migrations.RemoveField(
            model_name="historicaloffstudymedication",
            name="permanently_discontinued",
        ),
        migrations.RemoveField(
            model_name="historicaloffstudymedication",
            name="permanently_discontinued_reason",
        ),
        migrations.RemoveField(
            model_name="offstudymedication",
            name="expected_restart_date",
        ),
        migrations.RemoveField(
            model_name="offstudymedication",
            name="permanently_discontinued",
        ),
        migrations.RemoveField(
            model_name="offstudymedication",
            name="permanently_discontinued_reason",
        ),
        migrations.AddField(
            model_name="endofstudy",
            name="investigator_decision",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If reason is `investigator decision`, please explain ...",
            ),
        ),
        migrations.AddField(
            model_name="historicalendofstudy",
            name="investigator_decision",
            field=models.TextField(
                blank=True,
                max_length=500,
                null=True,
                verbose_name="If reason is `investigator decision`, please explain ...",
            ),
        ),
        migrations.AddField(
            model_name="historicaloffstudymedication",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Comment"),
        ),
        migrations.AddField(
            model_name="offstudymedication",
            name="comment",
            field=models.TextField(blank=True, null=True, verbose_name="Comment"),
        ),
        migrations.AlterField(
            model_name="endofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("diabetes", "Patient developed diabetes"),
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    ("toxicity", "Patient experienced an unacceptable toxicity"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                ],
                max_length=25,
                null=True,
                verbose_name="If withdrawn on CLINICAL grounds, please specify PRIMARY reason...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalendofstudy",
            name="clinical_withdrawal_reason",
            field=models.CharField(
                blank=True,
                choices=[
                    ("diabetes", "Patient developed diabetes"),
                    ("kidney_disease", "Development of chronic kidney disease"),
                    ("liver_disease", "Development of chronic liver disease"),
                    ("toxicity", "Patient experienced an unacceptable toxicity"),
                    (
                        "intercurrent_illness",
                        "Intercurrent illness which prevents further treatment",
                    ),
                    ("investigator_decision", "Investigator decision (specify below)"),
                    (
                        "OTHER",
                        "Other condition that justifies the discontinuation of treatment in the clinician’s opinion (specify below)",
                    ),
                ],
                max_length=25,
                null=True,
                verbose_name="If withdrawn on CLINICAL grounds, please specify PRIMARY reason...",
            ),
        ),
    ]



# Generated by Django 5.2.3 on 2025-07-24 03:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("meta_subject", "0226_followupvitals_waist_circumference_comment_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="followupvitals",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="followupvitals",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalfollowupvitals",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="historicalphysicalexam",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="waist_circumference_comment",
            field=models.TextField(
                blank=True,
                help_text="A reason not measured may be provided at anytime but is required at 36 and 48 months",
                null=True,
                verbose_name="If waist circumference not measured, please explain ...",
            ),
        ),
        migrations.AlterField(
            model_name="physicalexam",
            name="waist_circumference_measured",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                default="No",
                help_text="Waist circumference may be provided at anytime but is required at 36 and 48 months",
                max_length=15,
                verbose_name="Was the patient's waist circumference measured today?",
            ),
        ),
    ]
